/*****************************************************************************/
/*                                                                           */
/*  HyperPanel VMOS                     File "include/drv_itf.h"             */
/*  Constants and definitions for low level driver interface.                */
/*                                                                           */
/*  Author : AL/FA                      Last modification : 02/11/2016       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations =======================================================


         1  Defines
         2  Structures and typedefs
         3  Public variable
         4  Prototypes of public procedures


*/


#ifndef DRV_ITF_H                      /* If this file is not already        */
#define DRV_ITF_H                      /* included, include it.              */


/*
    1    Defines
    ____________
*/


#define MAXMAJ    256                 /* Numero maximum d'un major. <= 256  */
#define COND     (1<<7)



/*
    2    Structures and typedefs
    ____________________________
*/

typedef struct                         /* Contexte d'interface d'un IOD/MODD */
  BEGIN                                /* ---------------------------------- */
    USHORT     node                  ; /* Noeud distant                      */
    USHORT     aut                   ; /* Numero d'automate distant          */
    USHORT     vl                    ; /* Numero de voie logique distante    */
    USHORT     sessid                ; /* Identifiant de session (filtre)    */
    USHORT    *sub_sessid            ; /* Identifiants de session [255]      */
    USHORT    *sub_vl                ; /* Voies logiques          [255]      */
  END          Itf_ctx               ; /* ---------------------------------- */

typedef struct                         /* Contexte d'un Driver/Proto/Service */
  BEGIN                                /* ---------------------------------- */
    Itf_ctx   *itfctx                ; /* Table des contextes Itf_ctx.       */
    USHORT     nbiod                 ; /* Nombre d'IOD                       */
    USHORT     nbmodd                ; /* Nombre de MODD                     */
    UCHAR      sessid_cond_act[21]   ; /* b7:condition, b2-b0: action        */
  END          Drv_itf_ctx           ; /* ---------------------------------- */



/*
    3    Public variables
    _____________________
*/

extern Drv_itf_ctx drv_itf_ctx[]     ; /* Table des contextes internes.      */

/*
    4    Prototypes of public procedures
    ____________________________________
*/


#ifdef _DRO_

  IWORD drv_dps_info        (INT,INT*,INT*,INT*,INT*,const CHAR**            );
  IWORD drv_dps_init        (INT,INT,INT,INT                                 );
  IWORD drv_dps_end         (INT,INT,INT                                     );
  IWORD drv_dps_open        (INT,INT,INT,INT,UINT*,INT,INT,INT*              );
  IWORD drv_dps_close       (INT,INT                                         );
  IWORD drv_dps_connect     (INT,INT,UINT*,INT,INT                           );
  IWORD drv_dps_disconnect  (INT,INT,UINT*,INT                               );
  IWORD drv_dps_write       (INT,UCHAR*,UINT,UINT,INT,INT,INT                );
  IWORD drv_dps_read        (INT,UINT,UINT,INT,INT,INT                       );
  IWORD drv_dps_setval      (INT,INT,UINT*,INT                               );
  IWORD drv_dps_getval      (INT,INT,UINT*,INT                               );
  IWORD drv_dps_rpc         (INT,INT,INT,INT,UINT*,INT                       );
  IWORD drv_dps_evt         (INT,S_evt*                                      );
  IWORD vol_req             (INT,INT,INT,UCHAR*,INT,INT,UINT                 );
  IWORD drv_req             (INT,INT,INT,UCHAR*,INT,INT,UINT,UINT            );
  IWORD drv_resp            (INT,INT,UCHAR*,INT,INT,INT,INT,UINT             );
  IWORD drv_indrep          (INT,INT,INT                                     );
  IWORD drv_initdrv         (INT,INT,INT*                                    );
  IWORD chk_maj             (INT,IWORD*                                      );
  IWORD chk_iod             (INT,IWORD*,IWORD*                               );
  IWORD drv_vol_init        (INT,INT*                                        );
  IWORD drv_vol_mount       (INT,INT,INT,INT*,INT*                           );
  IWORD drv_vol_umount      (INT,INT                                         );
  IWORD drv_vol_vinfo       (INT,INT,INT*,INT*                               );
  IWORD drv_vol_credir      (INT,INT,CHAR*,INT                               );
  IWORD drv_vol_deldir      (INT,INT,CHAR*,INT                               );
  IWORD drv_vol_crefile     (INT,INT,CHAR*,UINT,INT                          );
  IWORD drv_vol_delfile     (INT,INT,CHAR*,INT                               );
  IWORD drv_vol_renfile     (INT,INT,CHAR*,CHAR*,INT                         );
  IWORD drv_vol_flist       (INT,INT,CHAR*,INT,UCHAR**,INT*                  );
  IWORD drv_vol_finfo       (INT,INT,CHAR*,INT,UINT*                         );
  IWORD drv_vol_fopen       (INT,INT,CHAR*,INT,INT,INT*,UINT*,INT*           );
  IWORD drv_vol_fclose      (INT,INT                                         );
  IWORD drv_vol_pseek       (INT,UINT,INT,INT*                               );
  IWORD drv_vol_fput        (INT,UCHAR*,INT,INT,INT,INT*                     );
  IWORD drv_vol_gseek       (INT,UINT,INT                                    );
  IWORD drv_vol_fget        (INT,INT,INT,UCHAR**,INT*,INT*                   );
  IWORD drv_vol_evt         (INT,S_evt*                                      );

#else

  IWORD drv_dps_info        (INT,INT*,INT*,INT*,INT*,const CHAR**            );
  IWORD drv_dps_init        (INT,INT,INT,UINT*,INT,INT,INT,INT               );
  IWORD drv_dps_end         (INT,INT,INT                                     );
  IWORD drv_dps_alloc       (INT,INT,INT,UINT*,INT,INT                       );
  IWORD drv_dps_free        (INT,INT,INT                                     );
  IWORD drv_dps_open_device (INT,INT,UINT*,INT                               );
  IWORD drv_dps_close_device(INT,INT                                         );
  IWORD drv_dps_alloc_sub   (INT,INT,INT,UINT*,INT,INT                       );
  IWORD drv_dps_free_sub    (INT,INT,INT                                     );
  IWORD drv_dps_connect     (INT,INT,UINT*,INT                               );
  IWORD drv_dps_listen      (INT,INT,UINT*,INT                               );
  IWORD drv_dps_disconnect  (INT,INT,INT                                     );
  IWORD drv_dps_abort       (INT,INT                                         );
  IWORD drv_dps_write       (INT,UCHAR*,UINT,UINT,INT,INT,INT                );
  IWORD drv_dps_read        (INT,UCHAR*,UINT,UINT,INT,INT,INT,INT            );
  IWORD drv_dps_setval      (INT,INT,UINT*,INT,INT                           );
  IWORD drv_dps_getval      (INT,INT,UINT*,INT                               );
  IWORD drv_dps_rpc         (INT,INT,INT,INT,UINT*,INT,INT                   );
  IWORD drv_dps_evt         (INT,S_evt*                                      );
  IWORD vol_req             (INT,INT,INT,UCHAR*,INT,INT,UINT                 );
  IWORD drv_req             (INT,INT,INT,UCHAR*,INT,UINT,UINT,INT            );
  IWORD drv_resp            (INT,INT,UCHAR*,INT,INT,INT,INT,UINT             );
  IWORD drv_indrep          (INT,INT,INT                                     );
  IWORD drv_initdrv         (INT,INT*                                        );
  IWORD chk_maj             (INT,IWORD*                                      );
  IWORD chk_iod             (INT,IWORD*,IWORD*,IWORD*,IWORD*                 );
  IWORD drv_vol_init        (INT,INT*                                        );
  IWORD drv_vol_mount       (INT,INT,INT,INT*,INT*                           );
  IWORD drv_vol_umount      (INT,INT                                         );
  IWORD drv_vol_vinfo       (INT,INT,INT*,INT*                               );
  IWORD drv_vol_credir      (INT,INT,UCHAR*,INT                              );
  IWORD drv_vol_deldir      (INT,INT,UCHAR*,INT                              );
  IWORD drv_vol_crefile     (INT,INT,UCHAR*,UINT,INT                         );
  IWORD drv_vol_delfile     (INT,INT,UCHAR*,INT                              );
  IWORD drv_vol_renfile     (INT,INT,UCHAR*,UCHAR*,INT                       );
  IWORD drv_vol_flist       (INT,INT,UCHAR*,INT,UCHAR**,INT*                 );
  IWORD drv_vol_finfo       (INT,INT,UCHAR*,INT,UINT*                        );
  IWORD drv_vol_fopen       (INT,INT,UCHAR*,INT,INT,INT*,UINT*,INT*          );
  IWORD drv_vol_fclose      (INT,INT                                         );
  IWORD drv_vol_pseek       (INT,UINT,INT,INT*                               );
  IWORD drv_vol_fput        (INT,UCHAR*,INT,INT,INT,INT*                     );
  IWORD drv_vol_gseek       (INT,UINT,INT                                    );
  IWORD drv_vol_fget        (INT,INT,INT,UCHAR**,INT*,INT*                   );
  IWORD drv_vol_evt         (INT,S_evt*                                      );

#endif


#endif                                 /* End of DRV_ITF_H.                  */
