/*****************************************************************************/
/*                                                                           */
/*  HyperPanel VMOS                     File "include/drvmio.h"              */
/*  Constants and definitions for I/O container drivers.                     */
/*                                                                           */
/*  Author : JYA                        Last modification : 02/11/2016       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations =======================================================


         1  Defines
         2  Structures and typedefs
            2.1  Structures de description drivers systemes (ROM)
            2.2  Structures de description drivers/protocoles/services (ROM)
            2.3  Structure de description d'un board (ROM)
            2.4  Structure de description du driver systeme ecran (ROM)
         3  Public variable
         4  Prototypes of public procedures


*/


#ifndef DRVMIO_H                       /* If this file is not already        */
#define DRVMIO_H                       /* included, include it.              */


/*
    1    Defines
    ____________
*/


/*
    2    Structures and typedefs
    ____________________________
*/


/*
   2.1 Structures de description drivers systemes (ROM)
   ----------------------------------------------------
*/

typedef struct                         /* Interface d'un driver systeme      */
  BEGIN                                /* ---------------------------------- */
    const CHAR      *drv_name        ; /* Nom du driver                      */
    UCHAR           typdrv           ; /* Vaut toujours 0 pour un driver sys */
                                       /*                                    */
    IWORD           (*init)()        ; /* Procedure d'initialisation         */
    IWORD           (*end )()        ; /* Procedure de finalisation          */
  END               Sdrv_desc        ; /* ---------------------------------- */


typedef struct                         /* Interface d'un device              */
  BEGIN                                /* ---------------------------------- */
    const CHAR      *dev_name        ; /* Nom du device systeme (inutilise)  */
    const void      *dev_desc        ; /* Low-level procedure addresses      */
    const void      *dev_def         ; /* Low-level parameters address       */
    const void      *drv_def         ; /* High-level parameters address      */
  END               Dev_link         ; /* ---------------------------------- */
 

typedef struct                         /* Description d'un driver systeme    */
  BEGIN                                /* ---------------------------------- */
    const Sdrv_desc *sdrv_desc       ; /* Ad. interface  du  driver          */
    const Dev_link  *dev_link        ; /* Ad. interfaces des devices         */
    UCHAR           nb_dev           ; /* Nombre de devices dans sdev_link[] */
  END               Sdrv_link        ; /* ---------------------------------- */
 

/*
   2.2 Structures de description drivers/protocoles/services (ROM)
   ---------------------------------------------------------------
*/
 
#ifndef _DRO_                          /* Nouvelle interface drivers.        */

typedef struct                         /* Interface entre couches            */
  BEGIN                                /* ---------------------------------- */
    IWORD           level            ; /* 1=driver, 2 et + = protocole       */
    CHAR            *name            ; /* Nom de la couche                   */

    IWORD           (*get_rctx)   () ; /* Retourne adresse contexte Req_ctx  */
    IWORD           (*get_info)   () ; /* Retourne adresse valeur demandee   */
                                       /*                                    */
    IWORD           (*connect)    () ; /* Demande connection sortante        */
    IWORD           (*listen)     () ; /* Demande connection entrante        */
    IWORD           (*disconnect) () ; /* Demande de deconnection            */
    IWORD           (*abort)      () ; /* Demande de rupture brutale         */
    IWORD           (*start)      () ; /* Demande de demarrage de flot       */
    IWORD           (*stop)       () ; /* Demande d'arret de flot            */
    IWORD           (*send)       () ; /* Demande d'emission                 */
    IWORD           (*receive)    () ; /* Demande de reception               */
    IWORD           (*setval)     () ; /* Demande d'ecriture de registres    */
    IWORD           (*getval)     () ; /* Demande de lecture de registres    */
    IWORD           (*rpc)        () ; /* Demande d'execution de commande    */
    IWORD           (*io)         () ; /* Demande d'entrees/sorties          */

  END               Tlcm_desc        ; /* ---------------------------------- */

typedef struct                         /* Interface d'un driver/proto/serv   */
  BEGIN                                /* ---------------------------------- */
    const CHAR      *drv_name        ; /* Nom du driver                      */
    UCHAR           typdrv           ; /* 001:dcar 010:proto 011:ser 101:dblk*/

    UCHAR           *initdone        ; /* Ad. drapeau d'initialisation       */
    IWORD           (*init   )()     ; /* Ad proc pour init specifique       */

    IWORD           aut              ; /* Numero de l'automate sous IT       */
    const S_trans   *trans           ; /* Ad. table de transitions           */
    const USHORT    *lim             ; /* Ad. table des limites des etats    */
    USHORT          *etat            ; /* Ad. table des variabled'etats    */
    const USHORT    *nbvl            ; /* Taille en USHORTs de "etat"        */
    const USHORT    *nbiod           ; /* Taille en USHORTs de sessid/con2vl */
    const USHORT    *nbmodd          ; /* Nb de contextes d'empilement       */
    const Tlcm_desc *tlcm            ; /* Procedures d'interface             */
    void            *adr             ; /* Adresse "utilisateur"              */
  END               Drv_desc         ; /* ---------------------------------- */

#else                                  /* Ancienne interface drivers.        */

typedef struct                         /* Interface d'un driver caractere    */
  BEGIN                                /* ---------------------------------- */
    const CHAR      *drv_name        ; /* Nom du driver                      */
    UCHAR           typdrv           ; /* 001:dcar 010:proto 011:ser 101:dblk*/

    UCHAR           *initdone        ; /* Ad. drapeau d'initialisation       */
    USHORT          *sessid          ; /* Ad. table identifiants de session. */
    USHORT          *con2vl          ; /* Ad. table association con-->vl     */
    UCHAR           *major           ; /* Ad variable major number           */
    UCHAR           *numdrv          ; /* Ad variable numero de driver       */
    IWORD           (*init   )()     ; /* Ad proc pour init specifique       */
    IWORD           (*reqevt )()     ; /* Ad proc pour evenements REQ_...    */
    IWORD           (*respevt)()     ; /* Ad proc pour evenements RESP_...   */
    IWORD           (*delcond)()     ; /* Ad proc pour supression conditions.*/
    IWORD           (*setindrep)()   ; /* Ad proc pour rerouter IND_REPORT   */

    IWORD           aut              ; /* Numero de l'automate sous IT       */
    const S_trans   *trans           ; /* Ad. table de transitions           */
    const USHORT    *lim             ; /* Ad. table des limites des etats    */
    USHORT          *etat            ; /* Ad. table des variabled'etats    */
    const USHORT    *nbvl            ; /* Nb total de voies logiques         */
    const USHORT    *nbcon           ; /* Nb de voies logiques "utilisateur" */
    const USHORT    *nbini           ; /* Nb de contextes d'initialisation.  */
    void            *adr             ; /* Adresse "utilisateur"              */
  END               Drv_desc         ; /* ---------------------------------- */

#endif                                 /* Fin du ifndef _DRO_.               */


typedef struct _pipe_desc              /* Interface support pipe des drivers */
  BEGIN                                /* ---------------------------------- */

    /* Interface a implementer pour la source ...............................*/

    void          (*get_info_src)()  ; /*                                    */
    IWORD         (*init_src)()      ; /*                                    */
    void          (*end_src)()       ; /*                                    */
    IWORD         (*input)()         ; /*                                    */
    IWORD         (*seek)()          ; /*                                    */
    void          (*free_src_data)() ; /*                                    */

    /* Interface a implementer pour le puits ................................*/

    void          (*get_info_sink)() ; /*                                    */
    IWORD         (*init_sink)()     ; /*                                    */
    void          (*end_sink)()      ; /*                                    */
    IWORD         (*output)()        ; /*                                    */

    /* Interface commune ....................................................*/

    void          (*event)()         ; /*                                    */
  END             Pipe_desc          ; /* ---------------------------------- */


typedef struct                         /* Description d'un driver caractere  */
  BEGIN                                /* ---------------------------------- */
    const Drv_desc  *drv_desc        ; /* Ad. interface  du  driver          */
    const Dev_link  *dev_link        ; /* Ad. liste d'interfaces des devices */
    UCHAR           nb_dev           ; /* Nombre de devices dans dev_link[]  */
    const Pipe_desc *pipe            ; /* Ad. interface pipe                 */
  END               Drv_link         ; /* ---------------------------------- */
 
 
/*
   2.3 Structure de description d'un board (ROM)
   ---------------------------------------------
*/
 
typedef struct                         /* Description d'un board             */
  BEGIN                                /* ---------------------------------- */
    const CHAR      *board_name      ; /* Nom du board                       */
    const Drv_link  *const* drv_link ; /* Ad. tab Ad. de drivers/proto/serv  */
  END               Board_link       ; /* ---------------------------------- */
 

/*
    3    Public variables
    _____________________
*/

extern const Board_link *board          ; /* Board description               */

extern const Sdrv_desc sdrv_vmio        ; /* VMIO      system drv interface  */
extern const Sdrv_desc sdrv_ram         ; /* RAM       system drv interface  */

extern const Sdrv_desc sdrv_asy         ; /* ASY       system drv interface  */
extern const Sdrv_desc sdrv_dma         ; /* DMA       system drv interface  */
extern const Sdrv_desc sdrv_eep         ; /* EEP       system drv interface  */
extern const Sdrv_desc sdrv_gpio        ; /* GPIO      system drv interface  */
extern const Sdrv_desc sdrv_i2c         ; /* I2C       system drv interface  */
extern const Sdrv_desc sdrv_int         ; /* INT       system drv interface  */
extern const Sdrv_desc sdrv_kbd         ; /* KEYBOARD  system drv interface  */
extern const Sdrv_desc sdrv_mse         ; /* MOUSE     system drv interface  */
extern const Sdrv_desc sdrv_pcr         ; /* PCR       system drv interface  */
extern const Sdrv_desc sdrv_pipe        ; /* PIPE      system drv interface  */
extern const Sdrv_desc sdrv_rcu         ; /* RCU       system drv interface  */
extern const Sdrv_desc sdrv_rslv        ; /* RESOLVE   system drv interface  */
extern const Sdrv_desc sdrv_usb         ; /* USB       system drv interface  */

extern const Drv_desc drv_desc_asy      ; /* ASY       char drv interface    */
extern const Drv_desc drv_desc_gpio     ; /* GPIO      char drv interface    */
extern const Drv_desc drv_desc_usbitf   ; /* USB       char drv interface    */

extern const Drv_desc drv_desc_adc      ; /* ADC       char drv interface    */
extern const Drv_desc drv_desc_asi      ; /* ASI       char drv interface    */
extern const Drv_desc drv_desc_aud      ; /* AUD       char drv interface    */
extern const Drv_desc drv_desc_dac      ; /* DAC       char drv interface    */
extern const Drv_desc drv_desc_den      ; /* DEN       char drv interface    */
extern const Drv_desc drv_desc_dmx_small; /* DMX       char drv interface    */
extern const Drv_desc drv_desc_dmx_full ; /* DMX       char drv interface    */
extern const Drv_desc drv_desc_eth      ; /* ETH       char drv interface    */
extern const Drv_desc drv_desc_fre      ; /* FRE       char drv interface    */
extern const Drv_desc drv_desc_kbditf   ; /* KBDITF    char drv interface    */
extern const Drv_desc drv_desc_led      ; /* LED       char drv interface    */
extern const Drv_desc drv_desc_pow      ; /* POW       char drv interface    */
extern const Drv_desc drv_desc_sec      ; /* SEC       char drv interface    */
extern const Drv_desc drv_desc_smc      ; /* SMC       char drv interface    */
extern const Drv_desc drv_desc_swi      ; /* SWI       char drv interface    */
extern const Drv_desc drv_desc_vid      ; /* VID       char drv interface    */

extern const Drv_desc drv_desc_dsk_ata  ; /* DSK_ATA   block drv interface   */

/*
    4    Prototypes of public procedures
    ____________________________________
*/


#endif                                 /* End of DRVMIO_H.                   */
