/*****************************************************************************/
/*                                                                           */
/*  HyperPanel VMOS                     File "src/space_appconf_stm32py.c"   */
/*  Configurable static data for stm32py target.                             */
/*                                                                           */
/*  Author : FA                         Last modification : 13/11/2018       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations ========================================================

    The module "space_appcont.c" contains all the static RAM data of the VMOS
(application container). These data are arrays wich size can be different,
depends on the target. Each array size is a define which value is define in 
a specific "space_xx.h" file. By using different copies of the "space_xx.h"
file, we can customize the sizeo of the RAM arrays.
    
*/


#include <stdtyp.l>                       /* Definitions and constantes.     */
#include <space_stm32py.h>                /* Sizing of static data.          */
#include <moteur.h>                       /* Task_grp                        */
#include <drv.h>                          /* Sys_driver                      */

extern const Dps_driver asy_driver      ;
extern const Dps_driver led_driver      ;
extern const Sys_driver gpio_driver     ;
extern const Dps_driver kbditf_driver   ;
extern const Sys_driver dac_driver      ;
extern const Sys_driver adc_driver      ;

IWORD init_vmk_fsm(char*,CHAR*,CHAR*); /* Prototype.                         */
IWORD init_myapp  (char*,CHAR*,CHAR*); /* Prototype.                         */

const Task_grp task_grp[] =            /* Definition des groupes de taches   */
  BEGIN                                /* ---------------------------------- */
                                       /* Groupes de taches "temps reel" ... */
                                       /* (group use autostart procstart)    */
    "vmos" , 1 , 1 , init_vmk_fsm   ,  /* VMOS HyperPanel.                   */
    "app"  , 1 , 1 , init_myapp     ,  /* VMK User tasks.                    */
                                       /* ---------------------------------- */
                                       /* Groupes de taches "standard" ..... */
                                       /* -                                  */
                                       /* ---------------------------------- */
    ""     , 9 , 9 , HNULL           , /* Marque de fin de liste ........... */
  END                                ; /* ---------------------------------- */

const Sys_driver * const vmos_driver[]=/* Drivers table for stm32m3.         */
  BEGIN                                /*                                    */
    (Sys_driver*)&asy_driver         , /* 0                                  */
    (Sys_driver*)&led_driver         , /* 1                                  */
    (Sys_driver*)&gpio_driver        , /* 2                                  */
    (Sys_driver*)&kbditf_driver      , /* 3                                  */
    (Sys_driver*)&dac_driver         , /* 4                                  */
    (Sys_driver*)&adc_driver         , /* 5                                  */
    HNULL                            , /* 6                                  */
  END                                ; /*                                    */
                                       /*                                    */

#include <../../vmos/sys/space_appcont.c> /* VMOS static data.               */
